@@ -204,3 +204,109 @@ orderMappedEdge<-function(trees,ordering=NULL){
 	}
 	return(trees)
 }
+
+# function gets sister node numbers or names
+# written by Liam J. Revell 2013
+getSisters<-function(tree,node,mode=c("number","label")){
+	mode<-mode[1]
+	if(is.character(node)) node<-match(node,c(tree$tip.label,tree$node.label))
+	sisters<-tree$edge[which(tree$edge[,1]==tree$edge[which(tree$edge[,2]==node),1]),2]
+	sisters<-setdiff(sisters,node)
+	if(mode=="number") return(sisters)
+	else if(mode=="label"){
+		result<-list()
+		n<-length(tree$tip.label)
+		if(is.null(tree$node.label)&&any(sisters>n)) result$nodes<-sisters[which(sisters>n)] 
+		else if(any(sisters>n)) result$nodes<-tree$node.label[sisters[which(sisters>n)]-n]
+		if(any(sisters<=n)) result$tips<-tree$tip.label[sisters[which(sisters<=n)]]
+		return(result)
+	}
+}
+
+# gets descendant node numbers
+# written by Liam Revell 2012, 2013
+getDescendants<-function(tree,node,curr=NULL){
+	if(is.null(curr)) curr<-vector()
+	daughters<-tree$edge[which(tree$edge[,1]==node),2]
+	curr<-c(curr,daughters)
+	if(length(curr)==0&&node<=length(tree$tip.label)) curr<-node
+	w<-which(daughters>=length(tree$tip))
+	if(length(w)>0) for(i in 1:length(w)) 
+		curr<-getDescendants(tree,daughters[w[i]],curr)
+	return(curr)
+}
+
+# function computes vcv for each state, and stores in array
+# written by Liam J. Revell 2011/2012
+multiC<-function(tree){
+	n<-length(tree$tip); m<-ncol(tree$mapped.edge)
+	# compute separate C for each state
+	mC<-list()
+	for(i in 1:m){
+		mtree<-list(edge=tree$edge,Nnode=tree$Nnode,tip.label=tree$tip.label,edge.length=tree$mapped.edge[,i])
+		class(mtree)<-"phylo"
+		mC[[i]]<-vcv.phylo(mtree)
+	}
+	return(mC)
+}
+
+# function pastes subtree onto tip
+# written by Liam Revell 2011
+paste.tree<-function(tr1,tr2){
+	if(length(tr2$tip)>1){ 
+		temp<-tr2$root.edge; tr2$root.edge<-NULL
+		tr1$edge.length[match(which(tr1$tip.label=="NA"),tr1$edge[,2])]<-tr1$edge.length[match(which(tr1$tip.label=="NA"),tr1$edge[,2])]+temp
+	}
+	tr.bound<-bind.tree(tr1,tr2,where=which(tr1$tip.label=="NA"))	
+	return(tr.bound)
+}
+
+# function drops entire clade
+# written by Liam Revell 2011
+drop.clade<-function(tree,tip){
+	tree<-drop.tip(tree,tip,trim.internal=FALSE)
+	while(sum(tree$tip.label=="NA")>1){
+		tree<-drop.tip(tree,"NA",trim.internal=FALSE)
+	}
+	return(tree)
+}
+
+# match type
+# written by Liam J. Revell 2012
+matchType<-function(type,types){
+	for(i in 1:length(types))
+		if(all(strsplit(type,split="")[[1]]==strsplit(types[i],split="")[[1]][1:length(strsplit(type,split="")[[1]])]))
+			type=types[i]
+	return(type)
+}
+
+# function returns random state with probability given by y
+# written by Liam Revell 2011
+
+rstate<-function(y){
+	if(length(y)==1) return(names(y)[1])
+	else {
+		cumy<-y; for(i in 2:length(y)) cumy[i]<-cumy[i-1]+y[i]
+		r<-runif(n=1); state=names(y)[1]
+		j=1; while(r>cumy[j]){ state=names(y)[j+1]; j<-j+1 } 
+		return(state)
+	}
+}
+
+# wraps around MatrixExp
+# written by Liam Revell 2011
+
+expm<-function(Y){
+	Z<-MatrixExp(Y); dimnames(Z)<-dimnames(Y)
+	return(Z)
+}
+	
+# function reorders simmap tree
+# written Liam Revell 2011
+reorderSimmap<-function(tree,order="cladewise"){
+	ntree<-reorder(tree,order)
+	o<-whichorder(ntree$edge[,2],tree$edge[,2])
+	ntree$mapped.edge<-tree$mapped.edge[o,]
+	ntree$maps<-tree$maps[o]
+	return(ntree)
+}
